set.seed(123)
#Linear Morphometrics####
##Loading in the data, converting to dataframe, removing NA's
library(readxl)
Indices <- read_excel("Indices.xlsx")

library(factoextra)
#Indices and factor creator
Indicesgroupsrow<- data.frame(Indices)
Indicesgroupsrow$Locomotion<- replace(Indicesgroupsrow$Locomotion,Indicesgroupsrow$Locomotion=="Terrestrial","Generalist")
Indicesgroups <- Indicesgroupsrow[,-1]
rownames(Indicesgroups) <- Indicesgroupsrow[,1]
Indicesnogroups <- Indicesgroups[,-1:-4]

library(plyr)
Species <- as.factor(Indicesgroups$Species)
Family <- as.factor(Indicesgroups$Family)
Habitat <- as.factor(Indicesgroups$Habitat)
Locomotion <-as.factor (Indicesgroups$Locomotion)

##Without N=1 and N=2 data for PERMANOVA and FDA
Indicesgroups.RmN1N2<-Indicesgroups[c(-1,-45,-46,-79),]
Indicesnogroups.RmN1N2<-Indicesgroups.RmN1N2[,-1:-4]
Species.RmN1N2 <- as.factor(Indicesgroups.RmN1N2$Species)
Family.RmN1N2 <- as.factor(Indicesgroups.RmN1N2$Family)
Habitat.RmN1N2 <- as.factor(Indicesgroups.RmN1N2$Habitat)
Locomotion.RmN1N2 <- as.factor(Indicesgroups.RmN1N2$Locomotion)

##Shapiro Wilks Normality test####
#Tutorialspoint (n.d.) How to perform shapiro test for all columns in an R data frame? Available at https://www.tutorialspoint.com/how-to-perform-shapiro-test-for-all-columns-in-an-r-data-frame (accessed 05 May 2023).
apply(Indicesnogroups,2,shapiro.test) ##for shapiro test 

##Assumption tests for similar multivariate dispersion####
library(vegan)
set.seed(123)
dist_permanova.RmN1N2 <- dist(Indicesnogroups.RmN1N2, method = "euclidean") 
##removing N=1 and N=2, as for the PERMANOVA we cannot use N=1 and N=2, they would result in a very unbalanced design, which PERMANOVA is not robust to Anderson, M.J., 2014. Permutational multivariate analysis of variance (PERMANOVA). Wiley statsref: statistics reference online, pp.1-15..

bds <- betadisper(dist_permanova.RmN1N2, Species.RmN1N2)
boxplot(bds)
plot(bds)
anova(bds)
permutest(bds)

##I. ebu must first be categorised as Hyaenidae before calculating these statistics for Family
Family[1]<-as.factor("Hyaenidae")
Family<-droplevels(Family)
dist_permanova <- dist(Indicesnogroups, method = "euclidean")
bdf <- betadisper(dist_permanova, Family) 
boxplot(bdf)
plot(bdf)
anova(bdf)
permutest(bdf)
Family<-as.factor(Indicesgroups$Family)

##PERMANOVAs####
IndicesgroupsIebuH <- Indicesgroups
IndicesgroupsIebuH$Family[1] = "Hyaenidae" #replace dataset with identical where I ebu is Hyaenidae
IndicesgroupsIebuH$Species <- revalue(Species, c("Ictitherium ebu"="Ie", "Chrysocyon brachyurus"="Cb", "Crocuta crocuta"="Cc", "Hyaena hyaena"="Hh","Proteles cristatus"="Pc", "Parahyaena brunnea"="Pb","Canis lupus"="Clu", "Vulpes vulpes"="Vv","Lupulella adusta"="La", "Canis latrans"="Cla"))

IndicesgroupsIebuH.RmN1N2 <- Indicesgroups.RmN1N2
IndicesgroupsIebuH.RmN1N2$Species <- revalue(Species.RmN1N2, c("Chrysocyon brachyurus"="Cb", "Crocuta crocuta"="Cc", "Hyaena hyaena"="Hh","Proteles cristatus"="Pc","Canis lupus"="Clu", "Vulpes vulpes"="Vv","Lupulella adusta"="La"))


library(pairwiseAdonis) 
#Martinez Arbizu, P. (2020). pairwiseAdonis: Pairwise multilevel comparison using adonis [Computer software]. R package version 0.4.1, https://github.com/pmartinezarbizu/pairwiseAdonis
set.seed(123)
adonis2(dist_permanova.RmN1N2 ~ Family / Species, data = Indicesgroups.RmN1N2, strata = Family.RmN1N2, permutations = 999, method = "euclidean")

PairwiseSMI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[5], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseSMI.RmN1N2, "PairwiseSMI.csv")
PairwiseBI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[6], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseBI.RmN1N2, "PairwiseBI.csv")
PairwiseHRI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[7], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseHRI.RmN1N2, "PairwiseHRI.csv")
PairwiseOLI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[8], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseOLI.RmN1N2, "PairwiseOLI.csv")
PairwiseURI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[9], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseURI.RmN1N2, "PairwiseURI.csv")
PairwiseFRI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[10], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseFRI.RmN1N2, "PairwiseFRI.csv")
PairwiseGI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[11], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseGI.RmN1N2, "PairwiseGI.csv")
PairwiseFEI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[12], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseFEI.RmN1N2, "PairwiseFEI.csv")
PairwiseHEI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[13], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseHEI.RmN1N2, "PairwiseHEI.csv")
PairwiseRRI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[14], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseRRI.RmN1N2, "PairwiseRRI.csv")
PairwiseMCRI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[15], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseMCRI.RmN1N2, "PairwiseMCRI.csv")
PairwiseHFI.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[16], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseHFI.RmN1N2, "PairwiseHFI.csv")
PairwiseMCHUM.RmN1N2 <- pairwise.adonis(IndicesgroupsIebuH.RmN1N2[17], IndicesgroupsIebuH.RmN1N2$Species, p.adjust.m = "holm")
write.csv(PairwiseMCHUM.RmN1N2, "PairwiseMCHUM.csv")

##NMDS####



#NMDS
#Holland (2021).  Data Analysis in the Geosciences GEOL 8370: Non-Metric Multidimensional Scaling (NMS). Available at http://strata.uga.edu/8370/lecturenotes/multidimensionalScaling.html (accessed 05 May 2023).
#Zorz (2019). NMDS Plots in R. Available at https://jkzorz.github.io/2019/06/06/NMDS.html (accessed 05 May 2023).
#Brown (2019).Running NMDS using ‘metaMDS’. Available at https://rstudio-pubs-static.s3.amazonaws.com/496936_2cda5f07e6044d7e9d521893e484a558.html (accessed 05 May 2023).

library(vegan)
set.seed(123)
nmds = metaMDS(Indicesnogroups,
               distance = "euclidean",
               k = 2,
               trymax = 999,
               autotransform=FALSE,
               noshare=FALSE)

# Shepards test/goodness of fit
library(vegan)
nmds$species

pdf("Linearshepard.pdf", width = 6.5,pointsize = 12)
stressplot(nmds)
dev.off()

gof <- goodness(nmds)
gof<- data.frame(gof)
rownames(gof) <- Indicesgroupsrow$Specimen
gof$Species = Indicesgroupsrow$Species

#extract NMDS scores (x and y coordinates) for sites from newer versions of vegan package
data.scores = as.data.frame(scores(nmds)$sites)

#add columns to data frame 
data.scores$Species = Indicesgroups$Species
data.scores$Family = Indicesgroups$Family
data.scores$Size = "a"
data.scores[c(2:13,23:34),5] = "b"
data.scores[c(14:22,45:58),5] = "b"

.data <- data.scores

#stackoverflow (2021).Change font face (to bold) of a single label in ggplot2 legend. Available at https://stackoverflow.com/questions/65186510/change-font-face-to-bold-of-a-single-label-in-ggplot2-legend (accessed 05 May 2023).
#Nichols (n.d.).Coloring for Colorblindness. Available at https://davidmathlogic.com/colorblind/#%23994F00-%23006CD1 (accessed 05 May 2023).

#ChatGPT was used to generate NMDS and FDA polygon plots. 
#Specific requests for the code listed below can be found here: https://chat.openai.com/share/504e7af0-38f2-4d93-a676-5d9de29d888f
#OpenAI (n.d.). ChatGPT. Available at https://openai.com/chatgpt (accessed 05 May 2023)

library(ggplot2)
library(ggtext)

# Calculate the hulls for each group
library(tidyverse)
hull_data <- data.scores %>%
  group_by(Species) %>%
  slice(chull(NMDS1, NMDS2))

xx = ggplot(data.scores, aes(x = NMDS1*-1, y = NMDS2, colour = Family, fill = Family)) +
  geom_point(aes( shape = Species, colour = Family, size = Size))+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA)) +
  scale_shape_manual(labels=c("Coyote","Wolf", "Maned wolf", "Spotted hyaena", "Striped hyaena", "*Ictitherium ebu*", "Side-striped jackal", "Brown hyaena", "Aardwolf", "Red fox"), values=c(0,2,3,4,5,19,6,7,8,9))+ 
  scale_color_manual(labels=c("Canidae","Hyaenidae", "*Ictitherium ebu*"),values=c("#DC3220", "#005AB5", "Black"))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5))+
  xlab("NMDS1")+ylab("NMDS2")+
  theme(text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14), 
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())

#Code generated by ChatGPT.
xx + aes(linetype = factor(Species))+
  geom_polygon(data = hull_data, aes(color = Family, ), size = 0.5, alpha = 0.15, show.legend = F)+
  scale_fill_manual(values=c("#DC3220", "#005AB5", "Black"))+
  scale_linetype_manual(values=c("solid","solid","solid","solid","solid","solid","solid","solid","solid","solid"))+
  guides(fill = "none",
         color = guide_legend(override.aes = list(size = 4),order = 2),
         linewidth = guide_legend(order=3),
         shape = guide_legend(override.aes = list(size = 4),order = 1))

ggsave("NMDSlinear.svg", device = "svg")
##FDA####
##Stepwise FDA 
# Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
#Statology (2020)  Linear Discriminant Analysis in R (Step-by-Step). Available at https://www.statology.org/linear-discriminant-analysis-in-r/ (accessed 05 May 2023). 

###Species####
library(klaR)
library(tidyverse)
library(caret)
library(mda)

#Find significant contributions without N=1 or N=2, as these are predictors
formulaAll=Species.RmN1N2~SMI+BI+HRI+OLI+URI+FRI+GI+FEI+HEI+RRI+MCRI+HFI+MCHUM
greedy.wilks(formulaAll,data=Indicesnogroups.RmN1N2, niveau = 0.05)

##Stepwise DFA to predict the species most similar to I.ebu
#Creating a new dataframe to separate into training and testing dataset
IndicesFDA <- Indicesgroups[,-3:-4]
IndicesFDA$Species <- as.factor(IndicesFDA$Species)
IndicesFDA$Family <- as.factor(IndicesFDA$Family)

#Separating I ebu, C. latrans and P. brunnea from the dataset
Iebu <- IndicesFDA[1,]
Iebu$Species <- droplevels(Iebu$Species)
Iebu$Family <- droplevels(Iebu$Family)

Clatrans <- IndicesFDA[79,]
Clatrans$Species <- droplevels(Clatrans$Species)
Clatrans$Family <- droplevels(Clatrans$Family)

Pbrunnea <- IndicesFDA[c(45:46),]
Pbrunnea$Species <- droplevels(Pbrunnea$Species)
Pbrunnea$Family <- droplevels(Pbrunnea$Family)

Indicestrain <- IndicesFDA[c(-1,-45,-46,-79),]
Indicestrain$Species <- droplevels(Indicestrain$Species)
Indicestrain$Family <- droplevels(Indicestrain$Family)


# Split the data into training (70%) and test set (30%) Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
set.seed(123)
training.samples <- Indicestrain$Species %>%
  createDataPartition(p = 0.7, list = FALSE)
train.data <- Indicestrain[training.samples, ]
test.data <- Indicestrain[-training.samples, ]

Species.RmN1N2<-train.data$Species
# Fit the model
fitspecies <- fda(Species.RmN1N2~FEI + BI + HFI + MCRI + GI + OLI + MCHUM + URI + 
                    HEI + FRI, data = train.data, method = bruto)

# Make predictions
predicted <- fitspecies %>% predict(test.data)
# Model accuracy
mean(predicted == test.data$Species)

#Predict Iebu and show where is plotted
predict(fitspecies,Iebu)
plot(fitspecies)+
  points(predict(fitspecies,Iebu, type = "var"))

IebuvarS<- predict(fitspecies,Iebu, type = "var")

#Predict Clatrans and show where is plotted
predict(fitspecies,Clatrans)
plot(fitspecies)+
  points(predict(fitspecies,Clatrans, type = "var"))

ClatransvarS<- predict(fitspecies,Clatrans, type = "var")

#Predict Pbrunnea and show where is plotted
predict(fitspecies,Pbrunnea)
plot(fitspecies)+
  points(predict(fitspecies,Pbrunnea, type = "var"))

PbrunneavarS<- predict(fitspecies,Pbrunnea, type = "var")

#Plot graph ## 
#extract CVA scores
Speciesscores <- data.frame(predict(fitspecies, type = "variates"))

#add columns to data frame 
Speciesscores$Species = train.data$Species
Speciesscores$Family = train.data$Family
Speciesscores$Size = "a"
Speciesscores[c(1:25,33:41),9] = "b"

rownames(Speciesscores) = rownames(train.data)
head(Speciesscores)

library(ggplot2)
library(ggtext)

# Calculate the hulls for each group
library(tidyverse)
hulldata2 <- Speciesscores %>%
  group_by(Species) %>%
  slice(chull(X1, X2))

#stackoverflow (2021).Change font face (to bold) of a single label in ggplot2 legend. Available at https://stackoverflow.com/questions/65186510/change-font-face-to-bold-of-a-single-label-in-ggplot2-legend (accessed 05 May 2023).
#Nichols (n.d.).Coloring for Colorblindness. Available at https://davidmathlogic.com/colorblind/#%23994F00-%23006CD1 (accessed 05 May 2023).

#ChatGPT was used to generate NMDS and FDA polygon plots. 
#Specific requests for the code listed below can be found here: https://chat.openai.com/share/504e7af0-38f2-4d93-a676-5d9de29d888f
#OpenAI (n.d.). ChatGPT. Available at https://openai.com/chatgpt (accessed 05 May 2023)

yy = ggplot(Speciesscores, aes(x = X1, y = X2, colour = Family, fill = Family)) +
  geom_point(aes( shape = Species, colour = Family, fill = Family, size = Size))+
  geom_point(aes(x=IebuvarS[,1],y=IebuvarS[,2],colour="Ictitherium ebu", shape = "Ictitherium ebu"), show.legend = F)+
  geom_point(aes(x=ClatransvarS[,1],y=ClatransvarS[,2],colour="Canis latrans", shape = "Canis latrans"), show.legend = F)+
  geom_point(aes(x=PbrunneavarS[1,1],y=PbrunneavarS[1,2],colour="Parahyena brunnea", shape = "Parahyena brunnea",size = "Parahyena brunnea"), show.legend = F)+
  geom_point(aes(x=PbrunneavarS[2,1],y=PbrunneavarS[2,2],colour="Parahyena brunnea", shape = "Parahyena brunnea",size = "Parahyena brunnea"), show.legend = F)+
  theme_classic()+
  theme(panel.border = element_rect(colour = "black", fill=NA)) +
  scale_shape_manual(labels=c("Wolf", "Maned wolf", "Spotted hyaena", "Striped hyaena", "Side-striped jackal", "Aardwolf", "Red fox","Ictitherium ebu","Coyote","Brown hyaena"), values=c(2,3,4,5,6,8,9,19,0,7))+
  scale_color_manual(labels=c("Canidae","Hyaenidae","Predictions"),values=c("#DC3220", "#005AB5", "Black","Black","Black","Black"))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5,5.5))+
  xlab("CV1 (44.56%)")+ylab("CV2 (27.06%)")+
  theme(text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14), 
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())

yy + aes(linetype = factor(Species))+
  geom_polygon(data = hulldata2, aes(color = Family, ), size = 0.5, alpha = 0.15, show.legend = F)+
  scale_fill_manual(values=c("#DC3220", "#005AB5", "Black"))+
  scale_linetype_manual(values=c("solid","solid","solid","solid","solid","solid","solid","solid","solid","solid"))+
  guides(fill = "none",
         color = guide_legend(override.aes = list(size = 4),order = 2),
         size = guide_legend(order=3),
         shape = guide_legend(override.aes = list(size = 4),order = 1))

ggsave("FDAlinear.svg", device = "svg")
###Family####
Indicesgroups$Species <- revalue(Species, c("Ictitherium ebu"="Ie", "Chrysocyon brachyurus"="Maned wolf", "Crocuta crocuta"="Spotted hyaena", "Hyaena hyaena"="Striped hyaena","Proteles cristatus"="Aardwolf", "Parahyaena brunnea"="Brown hyaena","Canis lupus"="Wolf", "Vulpes vulpes"="Red fox","Lupulella adusta"="Side-striped jackal", "Canis latrans"="Coyote"))
#Stepwise test
formulaAll=Family.RmN1N2~SMI+BI+HRI+OLI+URI+FRI+GI+FEI+HEI+RRI+MCRI+HFI+MCHUM
greedy.wilks(formulaAll,data=Indicesnogroups.RmN1N2, niveau = 0.05) 

##Stepwise DFA to predict the family most similar to I.ebu
#Creating a new dataframe to separate into training and testing dataset
IndicesF<-Indicesgroups

#Separating I ebu from the dataset
IebuF <- IndicesF[1,]
IebuF$Family<- as.factor(IebuF$Family)
IebuF$Family <- droplevels(IebuF$Family)

#Separating C.latrans from the dataset
ClatransF <- IndicesF[79,]
ClatransF$Family<- as.factor(ClatransF$Family)
ClatransF$Family <- droplevels(ClatransF$Family)

#Separating P.brunnea from the dataset
PbrunneaF <- IndicesF[45:46,]
PbrunneaF$Family<- as.factor(PbrunneaF$Family)
PbrunneaF$Family <- droplevels(PbrunneaF$Family)

IndicestrainF <- IndicesF[c(-1,-45,-46,-79),]
IndicestrainF$Family<- as.factor(IndicestrainF$Family)
IndicestrainF$Family <- droplevels(IndicestrainF$Family)

# Split the data into training (70%) and test set (30%) Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
set.seed(123)
training.samples <- IndicestrainF$Family %>%
  createDataPartition(p = 0.7, list = FALSE)
train.data <- IndicestrainF[training.samples, ]
test.data <- IndicestrainF[-training.samples, ]

# Fit the model
formulaStepwiseFP=train.data$Family ~ HEI + MCHUM + HFI + GI + SMI + FRI + URI

fitFP <- fda(formulaStepwiseFP,data=train.data, method = bruto)
fitFP

#Predict I.ebu 
predictedIebuF<-predict(fitFP,IebuF)
predictedIebuF
predictedIebuFvar<-predict(fitFP,IebuF, type = "var")

#Predict C.latrans
predictedClatransF<-predict(fitFP,ClatransF)
predictedClatransF
predictedClatransFvar<-predict(fitFP,ClatransF, type = "var")

#Predict P.brunnea
predictedPbrunneaF<-predict(fitFP,PbrunneaF)
predictedPbrunneaF
predictedPbrunneaFvar<-predict(fitFP,PbrunneaF, type = "var")


# Make predictions
predicted <- predict(fitFP,test.data)
# Model accuracy
mean(predicted == test.data$Family)

#Stripchart 
#Geeksforgeeks (n.d.). Create One Dimensional Scatterplots in R Programming – stripchart() Function .Available at https://www.geeksforgeeks.org/create-one-dimensional-scatterplots-in-r-programming-stripchart-function/ (accessed 05 May 2023)
Familyscores<- predict(fitFP, type = "variates")
Familyscores<-data.frame(Familyscores)
Familyscores$Family<-train.data$Family
Familyscores$Species<-train.data$Species
Familyscores$Size = "a"
Familyscores[c(1:23,32:36),4] = "b"
rownames(Familyscores) = rownames(train.data)

#If done by species
ggplot(Familyscores, aes(x=Familyscores, y=Species)) +
  geom_jitter(height = 0.2, aes( shape = Species, colour = Family, size = Size))+
  scale_shape_manual(values=c(2,3,4,5,6,8,9))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5))+ 
  scale_color_manual(values=c("#DC3220", "#005AB5"))+
  geom_vline(xintercept=predictedIebuFvar)+
  geom_vline(xintercept=predictedClatransFvar,linetype = "dotdash")+
  geom_vline(xintercept=predictedPbrunneaFvar,linetype = "longdash")+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA))+
  xlab("Canonical variate")+ylab("Species")+
  labs(tag = "a)")+
  theme(legend.position = "bottom",
        text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14),
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())+
  guides(shape = "none",
         color = guide_legend(override.aes = list(size = 4),order = 1),
         size = guide_legend(order=2))

ggsave("FDA Linear Family.svg", device = "svg")
###Locomotion####
##Stepwise DFA to predict the locomotor style most similar to I.ebu

formulaAll=Locomotion.RmN1N2~SMI+BI+HRI+OLI+URI+FRI+GI+FEI+HEI+RRI+MCRI+HFI+MCHUM
greedy.wilks(formulaAll,data=Indicesnogroups.RmN1N2, niveau = 0.05) 
#Creating a new dataframe to separate into training and testing dataset
IndicesL<-Indicesgroups

#Separating I ebu from dataset
IebuL <- IndicesL[1,]
IebuL$Locomotion<- as.factor(IebuL$Locomotion)
IebuL$Locomotion <- droplevels(IebuL$Locomotion)

#Separating C.latrans from the dataset
ClatransL <- IndicesL[79,]
ClatransL$Locomotion<- as.factor(ClatransL$Locomotion)
ClatransL$Locomotion <- droplevels(ClatransL$Locomotion)

#Separating P.brunnea from the dataset
PbrunneaL <- IndicesL[45:46,]
PbrunneaL$Locomotion<- as.factor(PbrunneaL$Locomotion)
PbrunneaL$Locomotion <- droplevels(PbrunneaL$Locomotion)

IndicestrainL <- IndicesL[c(-1,-45,-46,-79),]
IndicestrainL$Locomotion<- as.factor(IndicestrainL$Locomotion)
IndicestrainL$Locomotion <- droplevels(IndicestrainL$Locomotion)

# Split the data into training (70%) and test set (30%) Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
set.seed(123)
training.samples <- IndicestrainL$Locomotion %>%
  createDataPartition(p = 0.7, list = FALSE)
train.data <- IndicestrainL[training.samples, ]
test.data <- IndicestrainL[-training.samples, ]

#Formula stepwise analysis
formulaStepwiseLP=train.data$Locomotion ~ OLI + MCRI + HFI

fitLP <- fda(formulaStepwiseLP,data=train.data, method = bruto)
fitLP

#Predict I.ebu, C.latrans and P.brunnea
predictedIebuL<-predict(fitLP,IebuL)
predictedIebuL
predictedIebuLvar<-predict(fitLP,IebuL, type = "var")

predictedClatransL<-predict(fitLP,ClatransL)
predictedClatransL
predictedClatransLvar<-predict(fitLP,ClatransL, type = "var")

predictedPbrunneaL<-predict(fitLP,PbrunneaL)
predictedPbrunneaL
predictedPbrunneaLvar<-predict(fitLP,PbrunneaL, type = "var")

# Make predictions
predicted <- predict(fitLP,test.data)
# Model accuracy
mean(predicted == test.data$Locomotion)

#Stripchart 
#Geeksforgeeks (n.d.). Create One Dimensional Scatterplots in R Programming – stripchart() Function .Available at https://www.geeksforgeeks.org/create-one-dimensional-scatterplots-in-r-programming-stripchart-function/ (accessed 05 May 2023)

predictL<- predict(fitLP, type = "variates")
rownames(predictL) <-rownames(train.data)
predictL<-data.frame(predictL)
predictL$Species<- train.data$Species
predictL$Locomotion<- train.data$Locomotion
predictL$Size = "a"
predictL[c(1:25,32:41),4] = "b"

#If done by species
ggplot(predictL, aes(x=predictL, y=Species)) +
  geom_jitter(height = 0.2, aes( shape = Species, colour = Locomotion, size = Size))+
  scale_shape_manual(values=c(2,3,4,5,6,8,9))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5))+
  scale_color_manual(values=c("#DC3220", "#005AB5"))+
  geom_vline(xintercept=predictedIebuLvar)+
  geom_vline(xintercept=predictedClatransLvar, linetype = "dotdash")+
  geom_vline(xintercept=predictedPbrunneaLvar, linetype = "longdash")+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA))+
  xlab("Canonical variate")+ylab("Species")+
  labs(tag = "b)")+
  theme(legend.position = "bottom",
        text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14),
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())+
  guides(shape = "none",
         color = guide_legend(override.aes = list(size = 4),order = 1),
         size = guide_legend(order=2))

ggsave("FDA Linear Locomotion.svg", device = "svg")
###Habitat###########################
formulaAll=Habitat.RmN1N2~SMI+BI+HRI+OLI+URI+FRI+GI+FEI+HEI+RRI+MCRI+HFI+MCHUM
greedy.wilks(formulaAll,data=Indicesnogroups.RmN1N2, niveau = 0.05) 

##Stepwise DFA to predict the habitat most similar to I.ebu
#Creating a new dataframe to separate into training and testing dataset
IndicesH<-Indicesgroups

#Separating I ebu
IebuH <- IndicesH[1,]
IebuH$Habitat<- as.factor(IebuH$Habitat)
IebuH$Habitat <- droplevels(IebuH$Habitat)

#Separating C.latrans from the dataset
ClatransH <- IndicesH[79,]
ClatransH$Habitat<- as.factor(ClatransH$Habitat)
ClatransH$Habitat <- droplevels(ClatransH$Habitat)

#Separating P.brunnea from the dataset
PbrunneaH <- IndicesH[45:46,]
PbrunneaH$Habitat<- as.factor(PbrunneaH$Habitat)
PbrunneaH$Habitat <- droplevels(PbrunneaH$Habitat)

IndicestrainH <- IndicesH[c(-1,-45,-46,-79),]
IndicestrainH$Habitat<- as.factor(IndicestrainH$Habitat)
IndicestrainH$Habitat <- droplevels(IndicestrainH$Habitat)

# Split the data into training (70%) and test set (30%) Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
set.seed(123)
training.samples <- IndicestrainH$Habitat %>%
  createDataPartition(p = 0.7, list = FALSE)
train.data <- IndicestrainH[training.samples, ]
test.data <- IndicestrainH[-training.samples, ]

#Formula stepwise analysis
formulaStepwiseHP=train.data$Habitat ~ BI + HFI + FEI + MCRI + MCHUM
fitHP <- fda(formulaStepwiseHP,data=train.data, method = bruto)
fitHP

#Predict I.ebu
predictedIebuH<-predict(fitHP,IebuH)
predictedIebuH
predictedIebuHvar<-predict(fitHP,IebuH, type = "var")

#Predict C.latrans
predictedClatransH<-predict(fitHP,ClatransH)
predictedClatransH
predictedClatransHvar<-predict(fitHP,ClatransH, type = "var")

#Predict P.brunnea
predictedPbrunneaH<-predict(fitHP,PbrunneaH)
predictedPbrunneaH
predictedPbrunneaHvar<-predict(fitHP,PbrunneaH, type = "var")

# Make predictions
predicted <- predict(fitHP,test.data)
# Model accuracy
mean(predicted == test.data$Habitat)

#Stripchart 
#Geeksforgeeks (n.d.). Create One Dimensional Scatterplots in R Programming – stripchart() Function .Available at https://www.geeksforgeeks.org/create-one-dimensional-scatterplots-in-r-programming-stripchart-function/ (accessed 05 May 2023)

predictH<- predict(fitHP, type = "variates")
rownames(predictH) <-rownames(train.data)
predictH<-data.frame(predictH)
predictH$Habitat<- train.data$Habitat
predictH$Species<- train.data$Species
predictH$Size = "a"
predictH[c(1:22,31:37),4] = "b"

#If done by species
ggplot(predictH, aes(x=predictH, y=Species)) +
  geom_jitter(height = 0.2, aes( shape = Species, colour = Habitat, size = Size))+
  scale_shape_manual(values=c(2,3,4,5,6,8,9))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5))+
  scale_color_manual(values=c("#DC3220", "#005AB5"))+
  geom_vline(xintercept=predictedIebuHvar)+
  geom_vline(xintercept=predictedClatransHvar, linetype = "dotdash")+
  geom_vline(xintercept=predictedPbrunneaHvar, linetype = "longdash")+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA))+
  xlab("Canonical variate")+ylab("Species")+
  labs(tag = "c)")+
  theme(legend.position = "bottom",
        text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14),
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())+
  guides(shape = "none",
         color = guide_legend(override.aes = list(size = 4),order = 1),
         size = guide_legend(order=2))

ggsave("FDA Linear Habitat.svg", device = "svg")
##Boxplots####
library(plyr) 
#STHDA (n.d.).  ggplot2 box plot : Quick start guide - R software and data visualization. Available at http://www.sthda.com/english/wiki/ggplot2-box-plot-quick-start-guide-r-software-and-data-visualization (accessed 05 May 2023)

Indicesgroups$Species <- revalue(Species, c("Ictitherium ebu"="Ie", "Chrysocyon brachyurus"="Mw", "Crocuta crocuta"="Sp", "Hyaena hyaena"="St","Proteles cristatus"="Aw", "Parahyaena brunnea"="Bh","Canis lupus"="W", "Vulpes vulpes"="F","Lupulella adusta"="Sj", "Canis latrans"="C"))

#define plotting area as one row and two columns
SMI<-ggplot(Indicesgroups, aes(x=Species, y=SMI)) + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

BI<-ggplot(Indicesgroups, aes(x=Species, y=BI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

HRI<-ggplot(Indicesgroups, aes(x=Species, y=HRI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

HEI<-ggplot(Indicesgroups, aes(x=Species, y=HEI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

OLI<-ggplot(Indicesgroups, aes(x=Species, y=OLI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

URI<-ggplot(Indicesgroups, aes(x=Species, y=URI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

FRI<-ggplot(Indicesgroups, aes(x=Species, y=FRI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

GI<-ggplot(Indicesgroups, aes(x=Species, y=GI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

FEI<-ggplot(Indicesgroups, aes(x=Species, y=FEI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

RRI<-ggplot(Indicesgroups, aes(x=Species, y=RRI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

MCRI<-ggplot(Indicesgroups, aes(x=Species, y=MCRI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

MCHUM<-ggplot(Indicesgroups, aes(x=Species, y=MCHUM)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()

HFI<-ggplot(Indicesgroups, aes(x=Species, y=HFI)) + geom_boxplot() + theme(
  axis.text = element_text(size = 12, colour = "black"),
  axis.title = element_text(size = 14, colour = "black"),
  legend.text = element_text(size = 12),
  legend.title = element_text(size = 12, face  = 'bold')) + geom_boxplot()


library(ggpubr)
pdf("Boxplots.pdf", height = 30,width = 12,pointsize = 12)
ggarrange(SMI, BI, HRI, HEI, OLI, URI, FRI, GI, FEI, RRI, MCRI, MCHUM, HFI,
          labels = c("A", "B", "C", "D","E","F","G","H","I","J","K","L","M"),
          ncol = 2, nrow = 7)
dev.off()

Indicesgroups <- Indicesgroupsrow[,-1]
rownames(Indicesgroups) <- Indicesgroupsrow[,1]

#Truss####
library(factoextra)
library(readxl)

Truss <- read_excel("Truss.xlsx")
Truss <- data.frame(Truss)

Trussgrouprows <- data.frame(Truss)
Trussgrouprows$Locomotion<- replace(Trussgrouprows$Locomotion,Trussgrouprows$Locomotion=="Terrestrial","Generalist")
Trussgroup <- Trussgrouprows[,-1]
Species <- as.factor(Trussgroup$Species)
rownames(Trussgroup) <- Trussgrouprows[,1]
Trussnogroup <- Trussgroup[,-1:-4]

##Shapiro Wilks Normality test####
#Tutorialspoint (n.d.) How to perform shapiro test for all columns in an R data frame? Available at https://www.tutorialspoint.com/how-to-perform-shapiro-test-for-all-columns-in-an-r-data-frame (accessed 05 May 2023).
apply(Trussnogroup,2,shapiro.test)

##NMDS####
#Holland (2021).  Data Analysis in the Geosciences GEOL 8370: Non-Metric Multidimensional Scaling (NMS). Available at http://strata.uga.edu/8370/lecturenotes/multidimensionalScaling.html (accessed 05 May 2023).
#Zorz (2019). NMDS Plots in R. Available at https://jkzorz.github.io/2019/06/06/NMDS.html (accessed 05 May 2023).
#Brown (2019).Running NMDS using ‘metaMDS’. Available at https://rstudio-pubs-static.s3.amazonaws.com/496936_2cda5f07e6044d7e9d521893e484a558.html (accessed 05 May 2023).

library(vegan)
set.seed(123)
nmds = metaMDS(Trussnogroup,
               distance = "euclidean",
               k = 2,
               trymax = 999,
               autotransform=FALSE,
               noshare=FALSE)
nmds
plot(nmds)

# Shepards test/goodness of fit
library(vegan)
nmds$species

pdf("Trussshepard.pdf", width = 6.5,pointsize = 12)
stressplot(nmds)
dev.off()

gof <- goodness(nmds)
gof<- data.frame(gof)
rownames(gof) <- Trussgrouprows$Id
gof$Species = Trussgroup$Species
gof$Size = "a"
gof[c(2:43,51:52),3] = "b"

#extract NMDS scores (x and y coordinates) for sites from newer versions of vegan package
data.scores = as.data.frame(scores(nmds)$sites)

#add columns to data frame 
data.scores$Species = Trussgroup$Species
data.scores$Family = Trussgroup$Family
data.scores$Size = gof$Size

head(data.scores)
.data <- data.scores

#stackoverflow (2021).Change font face (to bold) of a single label in ggplot2 legend. Available at https://stackoverflow.com/questions/65186510/change-font-face-to-bold-of-a-single-label-in-ggplot2-legend (accessed 05 May 2023).
#Nichols (n.d.).Coloring for Colorblindness. Available at https://davidmathlogic.com/colorblind/#%23994F00-%23006CD1 (accessed 05 May 2023).

#ChatGPT was used to generate NMDS and FDA polygon plots. 
#Specific requests for the code listed below can be found here: https://chat.openai.com/share/504e7af0-38f2-4d93-a676-5d9de29d888f
#OpenAI (n.d.). ChatGPT. Available at https://openai.com/chatgpt (accessed 05 May 2023)


# Calculate the hulls for each group
library(ggplot2)
library(tidyverse)
library(ggtext)

hull_data <- data.scores %>%
  group_by(Species) %>%
  slice(chull(NMDS1, NMDS2))

xx = ggplot(data.scores, aes(x = NMDS1, y = NMDS2*-1, colour = Family, fill = Family)) +
  geom_point(aes( shape = Species, colour = Family, size = Size))+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA)) +
  scale_shape_manual(labels=c("Coyote","Wolf", "Maned wolf", "Spotted hyaena", "Striped hyaena", "*Ictitherium ebu*", "Side-striped jackal", "Brown hyaena", "Aardwolf", "Red fox"), values=c(0,2,3,4,5,19,6,7,8,9))+ 
  scale_color_manual(labels=c("Canidae","Hyaenidae", "*Ictitherium ebu*"),values=c("#DC3220", "#005AB5", "Black"))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5))+
  xlab("NMDS1")+ylab("NMDS2")+
  theme(text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14), 
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())

xx

#ChatGPT
xx + aes(linetype = factor(Species))+
  geom_polygon(data = hull_data, aes(color = Family, ), size = 0.5, alpha = 0.15, show.legend = F)+
  scale_fill_manual(values=c("#DC3220", "#005AB5", "Black"))+
  scale_linetype_manual(values=c("solid","solid","solid","solid","solid","solid","solid","solid","solid","solid"))+
  guides(fill = "none",
         color = guide_legend(override.aes = list(size = 4),order = 2),
         size = guide_legend(order=3),
         shape = guide_legend(override.aes = list(size = 4),order = 1))

ggsave("TrussNMDS.svg", device = "svg")
##FDA####
##Stepwise FDA 
# Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
#Statology (2020)  Linear Discriminant Analysis in R (Step-by-Step). Available at https://www.statology.org/linear-discriminant-analysis-in-r/ (accessed 05 May 2023). 

####Species####
library(klaR)
library(tidyverse)
library(caret)
library(mda)

##Stepwise DFA to predict the species most similar to I.ebu
#Formula analysis Species

#Separating I ebu, C.latrans and P.brunnea from the dataset
TrussFDA <- Trussgroup[-3:-4]
TrussFDA$Species <- as.factor(TrussFDA$Species)
TrussFDA$Family <- as.factor(TrussFDA$Family)

Iebu <- TrussFDA[72,]
Iebu$Species <- droplevels(Iebu$Species)
Iebu$Family <- droplevels(Iebu$Family)

Clatrans <- TrussFDA[1,]
Clatrans$Species <- droplevels(Clatrans$Species)
Clatrans$Family <- droplevels(Clatrans$Family)

Pbrunnea <- TrussFDA[c(51:52),]
Pbrunnea$Species <- droplevels(Pbrunnea$Species)
Pbrunnea$Family <- droplevels(Pbrunnea$Family)

Trusstrain <- TrussFDA[c(-1,-51,-52,-72),]
Trusstrain$Species <- droplevels(Trusstrain$Species)
Trusstrain$Family <- droplevels(Trusstrain$Family)

# Split the data into training (70%) and test set (30%) Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
set.seed(123)
training.samples <- Trusstrain$Species %>%
  createDataPartition(p = 0.7, list = FALSE)
train.data <- Trusstrain[training.samples, ]
test.data <- Trusstrain[-training.samples, ]

# Fit the model
fitfdaS <- fda(Species ~ X2.6 + X2.5 + X3.5 + X1.5 + X2.4 + X5.6 + X4.5 + X3.4 + X2.3 + X1.2 + X1.6,data=train.data, method=bruto)
# Make predictions
predicted <- fitfdaS %>% predict(test.data)
# Model accuracy
mean(predicted == test.data$Species)

#Predict Iebu
predict(fitfdaS,Iebu)
IebuvarS<- predict(fitfdaS,Iebu, type = "var")

predict(fitfdaS,Clatrans)
ClatransvarS<- predict(fitfdaS,Clatrans, type = "var")

predict(fitfdaS,Pbrunnea)
PbrunneavarS<- predict(fitfdaS,Pbrunnea, type = "var")
#Plot graph##
#extract CVA scores
Speciesscores <- data.frame(predict(fitfdaS, type = "variates"))

#add columns to data frame 
Speciesscores$Species = train.data$Species
Speciesscores$Family = train.data$Family
Speciesscores$Size = "a"
Speciesscores[c(1:31),9] = "b" 
rownames(Speciesscores) = rownames(train.data)
head(Speciesscores)

library(ggplot2)
library(ggtext)

# Calculate the hulls for each group
library(tidyverse)
hulldata2 <- Speciesscores %>%
  group_by(Species) %>%
  slice(chull(X1, X2))

#stackoverflow (2021).Change font face (to bold) of a single label in ggplot2 legend. Available at https://stackoverflow.com/questions/65186510/change-font-face-to-bold-of-a-single-label-in-ggplot2-legend (accessed 05 May 2023).
#Nichols (n.d.).Coloring for Colorblindness. Available at https://davidmathlogic.com/colorblind/#%23994F00-%23006CD1 (accessed 05 May 2023).

#ChatGPT was used to generate NMDS and FDA polygon plots. 
#Specific requests for the code listed below can be found here: https://chat.openai.com/share/504e7af0-38f2-4d93-a676-5d9de29d888f
#OpenAI (n.d.). ChatGPT. Available at https://openai.com/chatgpt (accessed 05 May 2023)

yy = ggplot(Speciesscores, aes(x = X1, y = X2)) +
  geom_point(size = 4, aes( shape = Species, colour = Family))+
  geom_point(size = 4, aes(x=IebuvarS[,1],y=IebuvarS[,2],colour="Ictitherium ebu", shape = "Ictitherium ebu"), show.legend = F)+
  geom_point(aes(x=ClatransvarS[,1],y=ClatransvarS[,2],colour="Canis latrans", shape = "Canis latrans"), show.legend = F)+
  geom_point(aes(x=PbrunneavarS[1,1],y=PbrunneavarS[1,2],colour="Parahyena brunnea", shape = "Parahyena brunnea",size = "Parahyena brunnea"), show.legend = F)+
  geom_point(aes(x=PbrunneavarS[2,1],y=PbrunneavarS[2,2],colour="Parahyena brunnea", shape = "Parahyena brunnea",size = "Parahyena brunnea"), show.legend = F)+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA)) +
  scale_shape_manual(labels=c("Wolf", "Maned wolf", "Spotted hyaena", "Striped hyaena", "Side-striped jackal", "Aardwolf", "Red fox","Ictitherium ebu","Coyote","Brown hyaena"), values=c(2,3,4,5,6,8,9,19,0,7))+
  scale_color_manual(labels=c("Canidae","Hyaenidae"),values=c("#DC3220", "#005AB5", "Black","Black","Black","Black"))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5,5.5))+
  xlab("CV1")+ylab("CV2")+
  theme(text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14), 
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())

yy + aes(linetype = factor(Species))+
  geom_polygon(data = hulldata2, aes(color = Family), fill = NA, size = 0.5, show.legend = F)

#Rotated
yy = ggplot(Speciesscores, aes(x = X2, y = X1*-1, colour = Family, fill = Family)) +
  geom_point(aes( shape = Species, colour = Family, size = Size))+
  geom_point(size = 2.5, aes(x=IebuvarS[,2],y=IebuvarS[,1]*-1,colour="Ictitherium ebu", shape = "Ictitherium ebu"), show.legend = F)+
  geom_point(aes(x=ClatransvarS[,2],y=ClatransvarS[,1]*-1,colour="Canis latrans", shape = "Canis latrans"), show.legend = F)+
  geom_point(aes(x=PbrunneavarS[1,2],y=PbrunneavarS[1,1]*-1,colour="Parahyena brunnea", shape = "Parahyena brunnea",size = "Parahyena brunnea"), show.legend = F)+
  geom_point(aes(x=PbrunneavarS[2,2],y=PbrunneavarS[2,1]*-1,colour="Parahyena brunnea", shape = "Parahyena brunnea",size = "Parahyena brunnea"), show.legend = F)+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA)) +
  scale_shape_manual(labels=c("Wolf", "Maned wolf", "Spotted hyaena", "Striped hyaena", "Side-striped jackal", "Aardwolf", "Red fox","Ictitherium ebu","Coyote","Brown hyaena"), values=c(2,3,4,5,6,8,9,19,0,7))+
  scale_color_manual(labels=c("Canidae","Hyaenidae","Predictions"),values=c("#DC3220", "#005AB5", "Black","Black","Black","Black"))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5,5.5,5.5))+
  xlab("CV2 (38.28%)")+ylab("CV1 (51.91%)")+
  theme(text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14), 
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())

#ChatGPT
yy + aes(linetype = factor(Species))+
  geom_polygon(data = hulldata2, aes(color = Family, ), size = 0.5, alpha = 0.15, show.legend = F)+
  scale_fill_manual(values=c("#DC3220", "#005AB5", "Black"))+
  scale_linetype_manual(values=c("solid","solid","solid","solid","solid","solid","solid","solid","solid","solid"))+
  guides(fill = "none",
         color = guide_legend(override.aes = list(size = 4),order = 2),
         size = guide_legend(order=3),
         shape = guide_legend(override.aes = list(size = 4),order = 1))



ggsave("TrussFDA Species.svg", device = "svg")
####Family####
##Stepwise DFA to predict the family most similar to I.ebu
#Creating a new dataframe to separate into training and testing dataset
library(plyr)
Trussgroup$Species <- revalue(Species, c("Ictitherium ebu"="Ie", "Chrysocyon brachyurus"="Maned wolf", "Crocuta crocuta"="Spotted hyaena", "Hyaena hyaena"="Striped hyaena","Proteles cristatus"="Aardwolf", "Parahyaena brunnea"="Brown hyaena","Canis lupus"="Wolf", "Vulpes vulpes"="Red fox","Lupulella adusta"="Side-striped jackal", "Canis latrans"="Coyote"))
TrussF<-Trussgroup

#Separating I.ebu from dataset
IebuF <- TrussF[72,]
IebuF$Family<- as.factor(IebuF$Family)
IebuF$Family <- droplevels(IebuF$Family)

#Separating C.latrans from the dataset
ClatransF <- TrussF[1,]
ClatransF$Family<- as.factor(ClatransF$Family)
ClatransF$Family <- droplevels(ClatransF$Family)

#Separating P.brunnea from the dataset
PbrunneaF <- TrussF[51:52,]
PbrunneaF$Family<- as.factor(PbrunneaF$Family)
PbrunneaF$Family <- droplevels(PbrunneaF$Family)

TrusstrainF <- TrussF[c(-1,-51,-52,-72),]
TrusstrainF$Family<- as.factor(TrusstrainF$Family)
TrusstrainF$Family <- droplevels(TrusstrainF$Family)

# Split the data into training (70%) and test set (30%) Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
set.seed(123)
training.samples <- TrusstrainF$Family %>%
  createDataPartition(p = 0.7, list = FALSE)
train.data <- TrusstrainF[training.samples, ]
test.data <- TrusstrainF[-training.samples, ]

# Fit the model
fitfdaF <- fda(Family ~ X2.6 + X2.5 + X3.5 + X1.5 + X2.4 + X5.6 + X4.5 + X3.4 + X2.3 + X1.2 + X1.6,data=train.data, method=bruto)
# Make predictions
predicted <- fitfdaF %>% predict(test.data)
# Model accuracy
mean(predicted == test.data$Family)

#Predict Iebu
predict(fitfdaF,IebuF)
IebuvarF<- predict(fitfdaF,IebuF, type = "var")

#Predict Clatrans
predict(fitfdaF,ClatransF)
ClatransvarF<- predict(fitfdaF,ClatransF, type = "var")

#Predict Pbrunnea
predict(fitfdaF,PbrunneaF)
PbrunneavarF<- predict(fitfdaF,PbrunneaF, type = "var")

#Stripchart 
#Geeksforgeeks (n.d.). Create One Dimensional Scatterplots in R Programming – stripchart() Function .Available at https://www.geeksforgeeks.org/create-one-dimensional-scatterplots-in-r-programming-stripchart-function/ (accessed 05 May 2023)
Familyscores<- predict(fitfdaF, type = "variates")
Familyscores<-data.frame(Familyscores)
Familyscores$Family<-train.data$Family
Familyscores$Species<-train.data$Species
Familyscores$Size = "a"
Familyscores[c(1:27),4] = "b"
rownames(Familyscores) = rownames(train.data)

#If done by species
ggplot(Familyscores, aes(x=Familyscores, y=Species)) +
  geom_jitter(height = 0.2, aes( shape = Species, colour = Family, size = Size))+
  scale_shape_manual(values=c(2,3,4,5,6,7,8,9,0))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5))+ 
  scale_color_manual(values=c("#DC3220", "#005AB5"))+
  geom_vline(xintercept=IebuvarF)+
  geom_vline(xintercept=ClatransvarF, linetype = "dotdash")+
  geom_vline(xintercept=PbrunneavarF, linetype = "longdash")+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA))+
  xlab("Canonical variate")+ylab("Species")+
  labs(tag = "a)")+
  theme(legend.position = "bottom",
        text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14),
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())+
  guides(shape = "none",
         color = guide_legend(override.aes = list(size = 4),order = 1),
         size = guide_legend(order=2))

ggsave("FDA Truss Family.svg", device = "svg")
####Locomotion####
##Stepwise DFA to predict the locomotor style most similar to I.ebu
#Creating a new dataframe to separate into training and testing dataset
TrussL<-Trussgroup

#Separating I ebu from dataset
IebuL <- TrussL[72,]
IebuL$Locomotion<- as.factor(IebuL$Locomotion)
IebuL$Locomotion <- droplevels(IebuL$Locomotion)

#Separating Clatrans from dataset
ClatransL <- TrussL[1,]
ClatransL$Locomotion<- as.factor(ClatransL$Locomotion)
ClatransL$Locomotion <- droplevels(ClatransL$Locomotion)

#Separating Pbrunnea from dataset
PbrunneaL <- TrussL[51:52,]
PbrunneaL$Locomotion<- as.factor(PbrunneaL$Locomotion)
PbrunneaL$Locomotion <- droplevels(PbrunneaL$Locomotion)

TrusstrainL <- TrussL[c(-1,-51,-52,-72),]
TrusstrainL$Locomotion<- as.factor(TrusstrainL$Locomotion)
TrusstrainL$Locomotion <- droplevels(TrusstrainL$Locomotion)

# Split the data into training (70%) and test set (30%) Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
set.seed(123)
training.samples <- TrusstrainL$Locomotion %>%
  createDataPartition(p = 0.7, list = FALSE)
train.data <- TrusstrainL[training.samples, ]
test.data <- TrusstrainL[-training.samples, ]

# Fit the model
fitfdaL <- fda(Locomotion ~ X2.6 + X2.5 + X3.5 + X1.5 + X2.4 + X5.6 + X4.5 + X3.4 + X2.3 + X1.2 + X1.6,data=train.data, method=bruto)

#Predict I.ebu
predictedIebuL<-predict(fitfdaL,IebuL)
predictedIebuL
predictedIebuLvar<-predict(fitfdaL,IebuL, type = "var")

#Predict Clatrans
predictedClatransL<-predict(fitfdaL,ClatransL)
predictedClatransL
predictedClatransLvar<-predict(fitfdaL,ClatransL, type = "var")

#Predict Pbrunnea
predictedPbrunneaL<-predict(fitfdaL,PbrunneaL)
predictedPbrunneaL
predictedPbrunneaLvar<-predict(fitfdaL,PbrunneaL, type = "var")

# Make predictions
predicted <- predict(fitfdaL,test.data)
# Model accuracy
mean(predicted == test.data$Locomotion)

#Stripchart 
#Geeksforgeeks (n.d.). Create One Dimensional Scatterplots in R Programming – stripchart() Function .Available at https://www.geeksforgeeks.org/create-one-dimensional-scatterplots-in-r-programming-stripchart-function/ (accessed 05 May 2023)
predictL<- predict(fitfdaL, type = "variates")
rownames(predictL) <-rownames(train.data)
predictL<-data.frame(predictL)
predictL$Locomotion<- train.data$Locomotion
predictL$Species<- train.data$Species
predictL$Size<- "a"
predictL[c(1:29),4] <- "b"

#If done by species
ggplot(predictL, aes(x=predictL, y=Species)) +
  geom_jitter(height = 0.2, aes( shape = Species, colour = Locomotion, size = Size))+
  scale_shape_manual(values=c(2,3,4,5,6,7,8,9,0))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5))+ 
  scale_color_manual(values=c("#DC3220", "#005AB5"))+
  geom_vline(xintercept=predictedIebuLvar,colour = "black")+
  geom_vline(xintercept=predictedClatransLvar, linetype = "dotdash")+
  geom_vline(xintercept=predictedPbrunneaLvar, linetype = "longdash")+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA))+
  xlab("Canonical variate")+ylab("Species")+
  labs(tag = "b)")+
  theme(legend.position = "bottom",
        text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14),
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())+
  guides(shape = "none",
         color = guide_legend(override.aes = list(size = 4),order = 1),
         size = guide_legend(order=2))

ggsave("FDA Truss Locomotion.svg", device = "svg")
####Habitat####
##Stepwise DFA to predict the habitat most similar to I.ebu
#Creating a new dataframe to separate into training and testing dataset
TrussH<-Trussgroup
#Separating I ebu from dataset
IebuH <- TrussH[72,]
IebuH$Habitat<- as.factor(IebuH$Habitat)
IebuH$Habitat <- droplevels(IebuH$Habitat)

#Separating Clatrans from dataset
ClatransH <- TrussH[1,]
ClatransH$Habitat<- as.factor(ClatransH$Habitat)
ClatransH$Habitat <- droplevels(ClatransH$Habitat)

#Separating Pbrunnea from dataset
PbrunneaH <- TrussH[51:52,]
PbrunneaH$Habitat<- as.factor(PbrunneaH$Habitat)
PbrunneaH$Habitat <- droplevels(PbrunneaH$Habitat)

TrusstrainH <- TrussH[c(-1,-51,-52,-72),]
TrusstrainH$Habitat<- as.factor(TrusstrainH$Habitat)
TrusstrainH$Habitat <- droplevels(TrusstrainH$Habitat)

# Split the data into training (70%) and test set (30%)  Kassambara (2018)  Articles - Classification Methods Essentials: Discriminant Analysis Essentials in R. Available at http://www.sthda.com/english/articles/36-classification-methods-essentials/146-discriminant-analysis-essentials-in-r/ (accessed 05 May 2023). 
set.seed(123)
training.samples <- TrusstrainH$Habitat %>%
  createDataPartition(p = 0.7, list = FALSE)
train.data <- TrusstrainH[training.samples, ]
test.data <- TrusstrainH[-training.samples, ]


# Fit the model
fitfdaH <- fda(Habitat ~ X2.6 + X2.5 + X3.5 + X1.5 + X2.4 + X5.6 + X4.5 + X3.4 + X2.3 + X1.2 + X1.6,data=train.data, method=bruto)

#Predict I.ebu
predictedH<-predict(fitfdaH,IebuH)
predictedH
predictedHvar<-predict(fitfdaH,IebuH, type = "var")

#Predict Clatrans
predictedClatransH<-predict(fitfdaH,ClatransH)
predictedClatransH
predictedClatransHvar<-predict(fitfdaH,ClatransH, type = "var")

#Predict Pbrunnea
predictedPbrunneaH<-predict(fitfdaH,PbrunneaH)
predictedPbrunneaH
predictedPbrunneaHvar<-predict(fitfdaH,PbrunneaH, type = "var")

# Make predictions
predicted <- predict(fitfdaH,test.data)
# Model accuracy
mean(predicted == test.data$Habitat)

#Stripchart 
#Geeksforgeeks (n.d.). Create One Dimensional Scatterplots in R Programming – stripchart() Function .Available at https://www.geeksforgeeks.org/create-one-dimensional-scatterplots-in-r-programming-stripchart-function/ (accessed 05 May 2023)
predictH<- predict(fitfdaH, type = "variates")
rownames(predictH) <-rownames(train.data)
predictH<-data.frame(predictH)
predictH$Habitat<- train.data$Habitat
predictH$Species<- train.data$Species
predictH$Size = "a"
predictH[c(1:28),4] = "b"

#If done by species
ggplot(predictH, aes(x=predictH, y=Species)) +
  geom_jitter(height = 0.2, aes( shape = Species, colour = Habitat, size = Size))+
  scale_shape_manual(values=c(2,3,4,5,6,7,8,9,0))+
  scale_size_manual(labels=c("\u02C2 20 kg","\u02C3 20 kg"),values = c(2.5,5.5))+ 
  scale_color_manual(values=c("#DC3220", "#005AB5"))+
  geom_vline(xintercept=predictedIebuHvar)+
  geom_vline(xintercept=predictedClatransHvar, linetype = "dotdash")+
  geom_vline(xintercept=predictedPbrunneaHvar, linetype = "longdash")+
  theme_classic() +
  theme(panel.border = element_rect(colour = "black", fill=NA))+
  xlab("Canonical variate")+ylab("Species")+
  labs(tag = "c)")+
  theme(legend.position = "bottom",
        text = element_text(family="", size=14),
        axis.title.y = element_text(face = "bold", size = 14),
        axis.title.x = element_text(face = "bold", size = 14, colour = "black"),
        legend.title = element_text(size = 14, colour = "black", face = "bold"),
        legend.text = element_markdown())+
  guides(shape = "none",
         color = guide_legend(override.aes = list(size = 4),order = 1),
         size = guide_legend(order=2))
ggsave("FDA Truss Habitat.svg", device = "svg")
